@@ -68,6 +68,8 @@ class Prompt:
                 self.id = hashlib.md5((self.template + self.answers).encode()).hexdigest()
             else:
                 self.id = hashlib.md5(self.template.encode()).hexdigest()
+        else:
+            self.id = hashlib.md5(self.template.encode()).hexdigest()
 
 
 class Prompts:
@@ -75,6 +77,7 @@ class Prompts:
     def from_url(cls, URL):
         res = requests.get(URL)
         prompts = json.loads(res.text)
+        # new_prompts = {x["id"]: Prompt(**x) for x in prompts}
         # prompts = []
         # for dic in dics:
         #     prompts.append(Prompt(**dic))
